Index: chrome/browser/task_manager/task_manager.cc |
diff --git a/chrome/browser/task_manager/task_manager.cc b/chrome/browser/task_manager/task_manager.cc |
index 1cb3c599f65b48ba0c007770585af3282a3ea224..38531d8232f53cc6086b8fcc116757231a5b0885 100644 |
--- a/chrome/browser/task_manager/task_manager.cc |
+++ b/chrome/browser/task_manager/task_manager.cc |
@@ -865,26 +865,26 @@ void TaskManagerModel::BytesRead(BytesReadParam param) { |
} |
// In order to retrieve the network usage, we register for URLRequestJob |
// notifications. Every time we get notified some bytes were read we bump a |
// counter of read bytes for the associated resource. When the timer ticks, |
// we'll compute the actual network usage (see the Refresh method). |
-void TaskManagerModel::OnJobAdded(URLRequestJob* job) { |
+void TaskManagerModel::OnJobAdded(net::URLRequestJob* job) { |
} |
-void TaskManagerModel::OnJobRemoved(URLRequestJob* job) { |
+void TaskManagerModel::OnJobRemoved(net::URLRequestJob* job) { |
} |
-void TaskManagerModel::OnJobDone(URLRequestJob* job, |
+void TaskManagerModel::OnJobDone(net::URLRequestJob* job, |
const URLRequestStatus& status) { |
} |
-void TaskManagerModel::OnJobRedirect(URLRequestJob* job, |
+void TaskManagerModel::OnJobRedirect(net::URLRequestJob* job, |
const GURL& location, |
int status_code) { |
} |
-void TaskManagerModel::OnBytesRead(URLRequestJob* job, const char* buf, |
+void TaskManagerModel::OnBytesRead(net::URLRequestJob* job, const char* buf, |
int byte_count) { |
int render_process_host_child_id = -1, routing_id = -1; |
ResourceDispatcherHost::RenderViewForRequest(job->request(), |
@@ -865,26 +865,26 @@ void TaskManagerModel::BytesRead(BytesReadParam param) { |
} |
-// In order to retrieve the network usage, we register for URLRequestJob |
+// In order to retrieve the network usage, we register for net::URLRequestJob |
// notifications. Every time we get notified some bytes were read we bump a |
// counter of read bytes for the associated resource. When the timer ticks, |